==> validator-1.0.3-sources.jar: com/humandevice/validator/widget/ValidatorEditText.java <==
package com.humandevice.validator.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.support.annotation.NonNull;
import android.support.annotation.Size;
import android.support.design.widget.TextInputEditText;
import android.util.AttributeSet;
import android.view.ViewParent;

import com.humandevice.validator.R;
import com.humandevice.validator.errors.Errors;
import com.humandevice.validator.rules.Rule;
import com.humandevice.validator.utils.ErrorTextWatcher;

import java.util.Set;

/**
 * TODO Dokumentacja
 *
 * @author Rafal Zajfert
 * @date 2016-07-20
 */
public class ValidatorEditText extends TextInputEditText implements ValidatorView {

	private ValidatorViewDelegator mDelegator = new ValidatorViewDelegator();

	public ValidatorEditText(Context context) {
		super(context);
	}

	public ValidatorEditText(Context context, AttributeSet attrs) {
		super(context, attrs);
		parseAttrs(context, attrs);
	}

	public ValidatorEditText(Context context, AttributeSet attrs, int defStyleAttr) {
		super(context, attrs, defStyleAttr);
		parseAttrs(context, attrs);
	}

	protected void parseAttrs(Context context, AttributeSet attrs) {
		TypedArray a = context.getTheme().obtainStyledAttributes(attrs, R.styleable.ValidatorView, 0, 0);
		try {
			setName(a.getString(R.styleable.ValidatorView_name));
		} finally {
			a.recycle();
		}
	}

	@Override
	public void setName(String name) {
		mDelegator.setName(name);
	}

	@Override
	public String getName() {
		return mDelegator.getName();
	}

	@Override
	public void addRule(@NonNull Rule rule, Rule... otherRules) {
		mDelegator.addRule(rule, otherRules);
		initTextWatcher();
	}

	@Override
	public void addRules(@Size(min = 1) Rule[] rules) {
		mDelegator.addRules(rules);
		initTextWatcher();
	}

	@Override
	public Set<Rule> getRules() {
		return mDelegator.getRules();
	}

	@Override
	public boolean validate(int maxPriority) {
		return mDelegator.validate(this, maxPriority);
	}

	@Override
	public Errors getErrors() {
		return mDelegator.getErrors();
	}

	@Override
	public boolean hasErrors() {
		return mDelegator.hasErrors();
	}

	@Override
	public void clearErrors() {
		mDelegator.clearErrors();
	}

	@Override
	public void showErrors() {
		ViewParent parent = getParent();
		if (parent instanceof ValidatorTextInputLayout){
			if (mDelegator.hasErrors()) {
				((ValidatorTextInputLayout) parent).setError(mDelegator.getErrors().getCombinedMessage());
				((ValidatorTextInputLayout) parent).setErrorEnabled(true);
			} else {
				((ValidatorTextInputLayout) parent).setError(null);
				((ValidatorTextInputLayout) parent).setErrorEnabled(false);
			}
		}else {
			mDelegator.showErrors(this);
		}
	}


	protected void initTextWatcher() {
		ErrorTextWatcher textWatcher = new ErrorTextWatcher(this);
		removeTextChangedListener(textWatcher); //remove old textWatcher if was previously added
		addTextChangedListener(textWatcher);
	}
}

==> validator-1.0.11-sources.jar: com/humandevice/validator/widget/ValidatorEditText.java <==
package com.humandevice.validator.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.support.annotation.NonNull;
import android.support.annotation.Size;
import android.support.design.widget.TextInputEditText;
import android.util.AttributeSet;
import android.view.ViewParent;

import com.humandevice.validator.R;
import com.humandevice.validator.errors.Errors;
import com.humandevice.validator.rules.Rule;
import com.humandevice.validator.utils.ErrorTextWatcher;

import java.util.Set;

/**
 * TODO Dokumentacja
 *
 * @author Rafal Zajfert
 * @date 2016-07-20
 */
public class ValidatorEditText extends TextInputEditText implements ValidatorView {

	private ValidatorViewDelegator mDelegator = new ValidatorViewDelegator();

	public ValidatorEditText(Context context) {
		super(context);
	}

	public ValidatorEditText(Context context, AttributeSet attrs) {
		super(context, attrs);
		parseAttrs(context, attrs);
	}

	public ValidatorEditText(Context context, AttributeSet attrs, int defStyleAttr) {
		super(context, attrs, defStyleAttr);
		parseAttrs(context, attrs);
	}

	protected void parseAttrs(Context context, AttributeSet attrs) {
		TypedArray a = context.getTheme().obtainStyledAttributes(attrs, R.styleable.ValidatorView, 0, 0);
		try {
			setName(a.getString(R.styleable.ValidatorView_name));
		} finally {
			a.recycle();
		}
	}

	@Override
	public void setName(String name) {
		mDelegator.setName(name);
	}

	@Override
	public String getName() {
		return mDelegator.getName();
	}

	@Override
	public void addRule(@NonNull Rule rule, Rule... otherRules) {
		mDelegator.addRule(rule, otherRules);
		initTextWatcher();
	}

	@Override
	public void addRules(@Size(min = 1) Rule[] rules) {
		mDelegator.addRules(rules);
		initTextWatcher();
	}

	@Override
	public Set<Rule> getRules() {
		return mDelegator.getRules();
	}

	@Override
	public boolean validate(int maxPriority) {
		return mDelegator.validate(this, maxPriority);
	}

	@Override
	public Errors getErrors() {
		return mDelegator.getErrors();
	}

	@Override
	public boolean hasErrors() {
		return mDelegator.hasErrors();
	}

	@Override
	public void clearErrors() {
		mDelegator.clearErrors();
	}

	@Override
	public void showErrors() {
		ViewParent parent=getParent().getParent();
		if (parent instanceof ValidatorTextInputLayout){
			if (mDelegator.hasErrors()) {
				((ValidatorTextInputLayout) parent).setError(mDelegator.getErrors().getCombinedMessage());
				((ValidatorTextInputLayout) parent).setErrorEnabled(true);
			} else {
				((ValidatorTextInputLayout) parent).setError(null);
				((ValidatorTextInputLayout) parent).setErrorEnabled(false);
			}
		}else {
			mDelegator.showErrors(this);
		}
	}


	protected void initTextWatcher() {
		ErrorTextWatcher textWatcher = new ErrorTextWatcher(this);
		removeTextChangedListener(textWatcher); //remove old textWatcher if was previously added
		addTextChangedListener(textWatcher);
	}
}
